@@ -1,6 +1,7 @@
 
 
 import Control.Exception (evaluate)
+import qualified Data.Text.IO
 import Data.Time (diffUTCTime, getCurrentTime)
 import System.Environment (getArgs)
 import Toml (parse)
@@ -11,8 +12,7 @@ main =
     filename <- case args of
       [filename] -> pure filename
       _ -> fail "Usage: benchmarker <file.toml>"
-    txt <- readFile filename
-    evaluate (length txt) -- readFile uses lazy IO, force it to load
+    txt <- Data.Text.IO.readFile filename
     start <- getCurrentTime
     evaluate (parse txt)
     stop <- getCurrentTime
